package gateway

import (
	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/cli"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/nfs"
	"shylinux.com/x/icebergs/base/tcp"
	"shylinux.com/x/icebergs/base/web"
	"shylinux.com/x/icebergs/core/code"
	kit "shylinux.com/x/toolkits"
	"shylinux.com/x/toolkits/task"

	"2025-dev.shylinux.com/x/20250215-cluster/src/travel"
)

type Gateway struct {
	travel.Travel
	script string `name:"script dev nodename port" help:"脚本"`
	list   string `name:"list space auto" help:"服务网关"`
}

func (s Gateway) Inputs(m *ice.Message, arg ...string) {
	switch arg[0] {
	case ice.DEV:
		m.SpaceListServer().Table(func(value ice.Maps) {
			m.Push(arg[0], value[mdb.TEXT])
		})
	case web.SPACE:
		m.Cmd("", s.Foreach).Table(func(value ice.Maps) {
			m.Push(arg[0], value[web.SPACE])
		})
	}
}
func (s Gateway) Script(m *ice.Message, arg ...string) {
	m.Option(cli.CTX_ARG, kit.JoinCmdArgs(
		ice.DEV, m.OptionDefault(ice.DEV, m.Option(ice.MSG_USERHOST)),
		tcp.NODENAME, m.OptionDefault(tcp.NODENAME, "$(hostname)-service"),
		tcp.PORT, m.OptionDefault(tcp.PORT, "9032"),
	))
	m.Cmdy(code.PUBLISH, nfs.CONTEXTS, nfs.BINARY)
}
func (s Gateway) List(m *ice.Message, arg ...string) {
	if len(arg) == 0 {
		info := web.Info
		stat := map[string]int{}
		m.Cmd(web.DREAM).Table(func(value ice.Maps) { stat[value[mdb.TYPE]]++ })
		m.PushRecord(stat)
		m.PushRecord(task.Info())
		m.Push("main", info.ServeMainCount)
		m.Push("get", info.ServeGetCount)
		m.Push("put", info.ServePutCount)
		m.Push("post", info.ServePostCount)
		m.Push("delete", info.ServeDeleteCount)
		m.Push("exec", info.SpaceCmdCount)
		m.Push("recv", info.SpaceReadCount)
		m.Push("read", kit.FmtSize(info.SpaceReadByte))
		m.Push("send", info.SpaceWriteCount)
		m.Push("write", kit.FmtSize(info.SpaceWriteByte))
		m.Push(nfs.VERSION, ice.Info.Make.Version)
		m.Push(mdb.TIME, ice.Info.Make.Time)
		m.Action(s.Foreach, s.Script)
	} else {
		m.Cmdy(web.SPACE, arg[0], m.PrefixKey())
	}
}

func init() { ice.Cmd("web.chat.dev.service.gateway", Gateway{}) }
